.. _detailed_api:

===
API
===

.. automodapi:: petrofit.correction
    :no-inheritance-diagram:

.. automodapi:: petrofit.fitting
    :no-inheritance-diagram:

.. automodapi:: petrofit.models
    :no-inheritance-diagram:
    :skip: Nuker2D
    :skip: Moffat2D
    :skip: EllipMoffat2D
    :skip: sersic_enclosed_model
    :skip: petrosian_model

.. automodapi:: petrofit.petrosian
    :no-inheritance-diagram:

.. automodapi:: petrofit.photometry
    :no-inheritance-diagram:

.. automodapi:: petrofit.segmentation
    :no-inheritance-diagram:

.. automodapi:: petrofit.utils
    :no-inheritance-diagram:

